==> ember__destroyable-4.0.0.tgz: ember__destroyable/README.md <==
# Installation
> `npm install --save @types/ember__destroyable`

# Summary
This package contains type definitions for @ember/destroyable (https://api.emberjs.com/ember/3.22/modules/@ember%2Fdestroyable).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/ember__destroyable.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/ember__destroyable/index.d.ts)
````ts
// Type definitions for non-npm package @ember/destroyable 4.0
// Project: https://api.emberjs.com/ember/3.22/modules/@ember%2Fdestroyable
// Definitions by: Chris Krycho <https://github.com/chriskrycho>
//                 Dan Freeman <https://github.com/dfreeman>
//                 James C. Davis <https://github.com/jamescdavis>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// Minimum TypeScript Version: 4.4

export function associateDestroyableChild<T extends object>(parent: object, child: T): T;

export function isDestroying(destroyable: object): boolean;

export function isDestroyed(destroyable: object): boolean;

export function destroy(destroyable: object): void;

export function assertDestroyablesDestroyed(): void;

export function enableDestroyableTracking(): void;

export function registerDestructor<T extends object>(
destroyable: T,
destructor: (destroyable: T) => void
): (destroyable: T) => void;

export function unregisterDestructor<T extends object>(
destroyable: T,
destructor: (destroyable: T) => void
): void;

````

### Additional Details
 * Last updated: Fri, 21 Jan 2022 19:02:05 GMT
 * Dependencies: none
 * Global values: none

# Credits
These definitions were written by [Chris Krycho](https://github.com/chriskrycho), [Dan Freeman](https://github.com/dfreeman), and [James C. Davis](https://github.com/jamescdavis).

==> ember__destroyable-4.0.1.tgz: ember__destroyable/README.md <==
# Installation
> `npm install --save @types/ember__destroyable`

# Summary
This package contains type definitions for @ember/destroyable (https://api.emberjs.com/ember/3.22/modules/@ember%2Fdestroyable).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/ember__destroyable.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/ember__destroyable/index.d.ts)
````ts
// Type definitions for non-npm package @ember/destroyable 4.0
// Project: https://api.emberjs.com/ember/3.22/modules/@ember%2Fdestroyable
// Definitions by: Chris Krycho <https://github.com/chriskrycho>
//                 Dan Freeman <https://github.com/dfreeman>
//                 James C. Davis <https://github.com/jamescdavis>
//                 Peter Wagenet <https://github.com/wagenet>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// Minimum TypeScript Version: 4.4

export function associateDestroyableChild<T extends object>(parent: object, child: T): T;

export function isDestroying(destroyable: object): boolean;

export function isDestroyed(destroyable: object): boolean;

export function destroy(destroyable: object): void;

export function assertDestroyablesDestroyed(): void;

export function enableDestroyableTracking(): void;

export function registerDestructor<T extends object>(
destroyable: T,
destructor: (destroyable: T) => void
): (destroyable: T) => void;

export function unregisterDestructor<T extends object>(
destroyable: T,
destructor: (destroyable: T) => void
): void;

````

### Additional Details
 * Last updated: Tue, 25 Oct 2022 20:03:09 GMT
 * Dependencies: none
 * Global values: none

# Credits
These definitions were written by [Chris Krycho](https://github.com/chriskrycho), [Dan Freeman](https://github.com/dfreeman), [James C. Davis](https://github.com/jamescdavis), and [Peter Wagenet](https://github.com/wagenet).
